==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoDbMigrationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.MongoDbReplication
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Describes how a MongoDB data migration should be performed
 * @property boostRUs The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
 * @property databases The databases on the source cluster to migrate to the target. The keys are the names of the databases.
 * @property replication Describes how changes will be replicated from the source to the target. The default is OneTime.
 * @property source Settings used to connect to the source cluster
 * @property target Settings used to connect to the target cluster
 * @property throttling Settings used to limit the resource usage of the migration
 */
public data class MongoDbMigrationSettingsArgs(
    public val boostRUs: Output<Int>? = null,
    public val databases: Output<Map<String, MongoDbDatabaseSettingsArgs>>,
    public val replication: Output<Either<String, MongoDbReplication>>? = null,
    public val source: Output<MongoDbConnectionInfoArgs>,
    public val target: Output<MongoDbConnectionInfoArgs>,
    public val throttling: Output<MongoDbThrottlingSettingsArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs =
        com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs.builder()
            .boostRUs(boostRUs?.applyValue({ args0 -> args0 }))
            .databases(
                databases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            )
            .replication(
                replication?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .source(source.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .throttling(throttling?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [MongoDbMigrationSettingsArgs].
 */
@PulumiTagMarker
public class MongoDbMigrationSettingsArgsBuilder internal constructor() {
    private var boostRUs: Output<Int>? = null

    private var databases: Output<Map<String, MongoDbDatabaseSettingsArgs>>? = null

    private var replication: Output<Either<String, MongoDbReplication>>? = null

    private var source: Output<MongoDbConnectionInfoArgs>? = null

    private var target: Output<MongoDbConnectionInfoArgs>? = null

    private var throttling: Output<MongoDbThrottlingSettingsArgs>? = null

    /**
     * @param value The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
     */
    @JvmName("jemlglttkvymivuq")
    public suspend fun boostRUs(`value`: Output<Int>) {
        this.boostRUs = value
    }

    /**
     * @param value The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("gesbcylnranqeeyg")
    public suspend fun databases(`value`: Output<Map<String, MongoDbDatabaseSettingsArgs>>) {
        this.databases = value
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("aompkkvmdujsmhar")
    public suspend fun replication(`value`: Output<Either<String, MongoDbReplication>>) {
        this.replication = value
    }

    /**
     * @param value Settings used to connect to the source cluster
     */
    @JvmName("gureegvgfjhyftmw")
    public suspend fun source(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.source = value
    }

    /**
     * @param value Settings used to connect to the target cluster
     */
    @JvmName("aaghmhkolrtvfaet")
    public suspend fun target(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.target = value
    }

    /**
     * @param value Settings used to limit the resource usage of the migration
     */
    @JvmName("pkaavroekxmkgbuf")
    public suspend fun throttling(`value`: Output<MongoDbThrottlingSettingsArgs>) {
        this.throttling = value
    }

    /**
     * @param value The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
     */
    @JvmName("pwylbduldpwmuohj")
    public suspend fun boostRUs(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.boostRUs = mapped
    }

    /**
     * @param value The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("xsxygtqegjfjnqlm")
    public suspend fun databases(`value`: Map<String, MongoDbDatabaseSettingsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databases = mapped
    }

    /**
     * @param argument The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("mdmjgbybdschxlxb")
    public suspend fun databases(
        vararg
        argument: Pair<String, suspend MongoDbDatabaseSettingsArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                MongoDbDatabaseSettingsArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.databases = mapped
    }

    /**
     * @param values The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("xvfxhsqmkoqldoyq")
    public fun databases(vararg values: Pair<String, MongoDbDatabaseSettingsArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databases = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("ydgmpwkdpidyuhgy")
    public suspend fun replication(`value`: Either<String, MongoDbReplication>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("oydvlrqjhkqnivgy")
    public fun replication(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MongoDbReplication>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("pkyadmfauwkhunvs")
    public fun replication(`value`: MongoDbReplication) {
        val toBeMapped = Either.ofRight<String, MongoDbReplication>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Settings used to connect to the source cluster
     */
    @JvmName("iekvgyldukngjuss")
    public suspend fun source(`value`: MongoDbConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument Settings used to connect to the source cluster
     */
    @JvmName("igkafphdtdwnxfwn")
    public suspend fun source(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    /**
     * @param value Settings used to connect to the target cluster
     */
    @JvmName("tqixvaxwusjbndep")
    public suspend fun target(`value`: MongoDbConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param argument Settings used to connect to the target cluster
     */
    @JvmName("trtibhjyfkwsldqo")
    public suspend fun target(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.target = mapped
    }

    /**
     * @param value Settings used to limit the resource usage of the migration
     */
    @JvmName("kkhqjfrolnqikaau")
    public suspend fun throttling(`value`: MongoDbThrottlingSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.throttling = mapped
    }

    /**
     * @param argument Settings used to limit the resource usage of the migration
     */
    @JvmName("uuaeodolevbwxydm")
    public suspend fun throttling(argument: suspend MongoDbThrottlingSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbThrottlingSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.throttling = mapped
    }

    internal fun build(): MongoDbMigrationSettingsArgs = MongoDbMigrationSettingsArgs(
        boostRUs = boostRUs,
        databases = databases ?: throw PulumiNullFieldException("databases"),
        replication = replication,
        source = source ?: throw PulumiNullFieldException("source"),
        target = target ?: throw PulumiNullFieldException("target"),
        throttling = throttling,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoDbMigrationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.MongoDbReplication
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Describes how a MongoDB data migration should be performed
 * @property boostRUs The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
 * @property databases The databases on the source cluster to migrate to the target. The keys are the names of the databases.
 * @property replication Describes how changes will be replicated from the source to the target. The default is OneTime.
 * @property source Settings used to connect to the source cluster
 * @property target Settings used to connect to the target cluster
 * @property throttling Settings used to limit the resource usage of the migration
 */
public data class MongoDbMigrationSettingsArgs(
    public val boostRUs: Output<Int>? = null,
    public val databases: Output<Map<String, MongoDbDatabaseSettingsArgs>>,
    public val replication: Output<Either<String, MongoDbReplication>>? = null,
    public val source: Output<MongoDbConnectionInfoArgs>,
    public val target: Output<MongoDbConnectionInfoArgs>,
    public val throttling: Output<MongoDbThrottlingSettingsArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs =
        com.pulumi.azurenative.datamigration.inputs.MongoDbMigrationSettingsArgs.builder()
            .boostRUs(boostRUs?.applyValue({ args0 -> args0 }))
            .databases(
                databases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value.let({ args0 -> args0.toJava() }))
                    }).toMap()
                }),
            )
            .replication(
                replication?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .source(source.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .target(target.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .throttling(throttling?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [MongoDbMigrationSettingsArgs].
 */
@PulumiTagMarker
public class MongoDbMigrationSettingsArgsBuilder internal constructor() {
    private var boostRUs: Output<Int>? = null

    private var databases: Output<Map<String, MongoDbDatabaseSettingsArgs>>? = null

    private var replication: Output<Either<String, MongoDbReplication>>? = null

    private var source: Output<MongoDbConnectionInfoArgs>? = null

    private var target: Output<MongoDbConnectionInfoArgs>? = null

    private var throttling: Output<MongoDbThrottlingSettingsArgs>? = null

    /**
     * @param value The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
     */
    @JvmName("trmehkwgdktxpoqr")
    public suspend fun boostRUs(`value`: Output<Int>) {
        this.boostRUs = value
    }

    /**
     * @param value The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("ddviimayqevtpgyd")
    public suspend fun databases(`value`: Output<Map<String, MongoDbDatabaseSettingsArgs>>) {
        this.databases = value
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("bbbwqtbncvvahhri")
    public suspend fun replication(`value`: Output<Either<String, MongoDbReplication>>) {
        this.replication = value
    }

    /**
     * @param value Settings used to connect to the source cluster
     */
    @JvmName("ykqirrqynuypujuh")
    public suspend fun source(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.source = value
    }

    /**
     * @param value Settings used to connect to the target cluster
     */
    @JvmName("uuwxkqdfleuiucli")
    public suspend fun target(`value`: Output<MongoDbConnectionInfoArgs>) {
        this.target = value
    }

    /**
     * @param value Settings used to limit the resource usage of the migration
     */
    @JvmName("gnisikvprrxdowrm")
    public suspend fun throttling(`value`: Output<MongoDbThrottlingSettingsArgs>) {
        this.throttling = value
    }

    /**
     * @param value The RU limit on a CosmosDB target that collections will be temporarily increased to (if lower) during the initial copy of a migration, from 10,000 to 1,000,000, or 0 to use the default boost (which is generally the maximum), or null to not boost the RUs. This setting has no effect on non-CosmosDB targets.
     */
    @JvmName("kvgmucwswvscpmbv")
    public suspend fun boostRUs(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.boostRUs = mapped
    }

    /**
     * @param value The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("xbdyltekpapampub")
    public suspend fun databases(`value`: Map<String, MongoDbDatabaseSettingsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databases = mapped
    }

    /**
     * @param argument The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("cldshtdvgwkvomxm")
    public suspend fun databases(
        vararg
        argument: Pair<String, suspend MongoDbDatabaseSettingsArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                MongoDbDatabaseSettingsArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.databases = mapped
    }

    /**
     * @param values The databases on the source cluster to migrate to the target. The keys are the names of the databases.
     */
    @JvmName("ujahfyhuqpfutpjp")
    public fun databases(vararg values: Pair<String, MongoDbDatabaseSettingsArgs>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.databases = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("eijajqikhmrsvwav")
    public suspend fun replication(`value`: Either<String, MongoDbReplication>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("fyucpdjhwvfftuqp")
    public fun replication(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MongoDbReplication>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Describes how changes will be replicated from the source to the target. The default is OneTime.
     */
    @JvmName("vlkegpafdnrqwwro")
    public fun replication(`value`: MongoDbReplication) {
        val toBeMapped = Either.ofRight<String, MongoDbReplication>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replication = mapped
    }

    /**
     * @param value Settings used to connect to the source cluster
     */
    @JvmName("kuwojipjqwfnmwbv")
    public suspend fun source(`value`: MongoDbConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param argument Settings used to connect to the source cluster
     */
    @JvmName("psltkpjdclsfntqd")
    public suspend fun source(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.source = mapped
    }

    /**
     * @param value Settings used to connect to the target cluster
     */
    @JvmName("cshvttadawfjxvbo")
    public suspend fun target(`value`: MongoDbConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param argument Settings used to connect to the target cluster
     */
    @JvmName("qtpdpxqnmjratkkc")
    public suspend fun target(argument: suspend MongoDbConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.target = mapped
    }

    /**
     * @param value Settings used to limit the resource usage of the migration
     */
    @JvmName("trichevoumrwhmqd")
    public suspend fun throttling(`value`: MongoDbThrottlingSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.throttling = mapped
    }

    /**
     * @param argument Settings used to limit the resource usage of the migration
     */
    @JvmName("rrgvkmegjvykdlqm")
    public suspend fun throttling(argument: suspend MongoDbThrottlingSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MongoDbThrottlingSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.throttling = mapped
    }

    internal fun build(): MongoDbMigrationSettingsArgs = MongoDbMigrationSettingsArgs(
        boostRUs = boostRUs,
        databases = databases ?: throw PulumiNullFieldException("databases"),
        replication = replication,
        source = source ?: throw PulumiNullFieldException("source"),
        target = target ?: throw PulumiNullFieldException("target"),
        throttling = throttling,
    )
}
